package com.community.pocket.repository;

import com.community.pocket.entity.po.EmailCode;
import com.mongodb.client.result.DeleteResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.stereotype.Repository;
import org.springframework.util.StringUtils;

/**
 * 邮件管理
 */
@Repository
public class EmailDao extends BaseDao<EmailCode> {

    private static final Logger LOG = LoggerFactory.getLogger(EmailDao.class);

    //检查验证码
    public boolean checkCode(String email,String code){
        if(!StringUtils.isEmpty(email)&&!StringUtils.isEmpty(code)){
            return mongoTemplate.exists(new Query().addCriteria(Criteria.where("emailAddress").is(email).and("code").is(code)), entityClass());
        }else {
            return false;
        }
    }

    public boolean clearEmail(String email){
       DeleteResult result= mongoTemplate.remove(new Query(Criteria.where("emailAddress").is(email)),entityClass());
       return result.wasAcknowledged();
    }
    
    @Override
    public EmailCode save(EmailCode emailCode) {
        try {
            return mongoTemplate.save(emailCode);
        } catch (Exception e) {
            e.printStackTrace();
            LOG.error(e.toString());
        }
        return null;
    }

    @Override
    public Class<EmailCode> entityClass() {
        return EmailCode.class;
    }
}
