package com.community.pocket.repository.android;

import com.community.pocket.entity.po.android.VisitorPeople;
import com.community.pocket.entity.vo.android.QueryVisitorPeople;
import com.community.pocket.entity.vo.android.UserRegister;
import com.community.pocket.repository.BaseDao;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.regex.Pattern;

/**
 * 预约人信息
 */
@Repository
@ConfigurationProperties(prefix = "register")
public class VisitorPeopleDao extends BaseDao<VisitorPeople> {

    private static final Logger LOG = LoggerFactory.getLogger(VisitorPeopleDao.class);

    private List<String> visitorList;

    public void setVisitorList(List<String> visitorList) {
        this.visitorList = visitorList;
    }

    public List<String> getVisitorList() {
        return visitorList;
    }

    //加载预约人列表
    public List<VisitorPeople> loadAll(QueryVisitorPeople queryVisitorPeople) {
        if (queryVisitorPeople.getOutPeople()) {
            return mongoTemplate.find(new Query(Criteria.where("username").regex(Pattern.compile(".*" + queryVisitorPeople.getName() + ".*"))), entityClass());
        } else {
            return mongoTemplate.find(new Query(new Criteria().andOperator(
                    Criteria.where("username").regex(Pattern.compile(".*" + queryVisitorPeople.getName() + ".*")),
                    Criteria.where("username").ne(queryVisitorPeople.getUsername())))
                    , entityClass());
        }
    }

    @Override
    public VisitorPeople save(VisitorPeople visitorPeople) {
        try {
            return mongoTemplate.save(visitorPeople);
        } catch (Exception e) {
            e.printStackTrace();
            LOG.error(e.toString());
        }
        return null;
    }

    @Override
    public Class<VisitorPeople> entityClass() {
        return VisitorPeople.class;
    }

    public VisitorPeople save(UserRegister userRegister) {
        VisitorPeople visitorPeople = new VisitorPeople();
        visitorPeople.setUsername(userRegister.getUsername());
        visitorPeople.setTime(visitorList);
        return save(visitorPeople);
    }
}
